# enrollment
Connect Enrollment Service allows users to claim the ownership of a device which is not yet assigned to an account. A device without an assigned account can be a device purchased from the open market (OEM dealer) or a device transferred from an account to another. More information in [Device ownership: First-to-claim](/docs/current/connecting/device-ownership-first-to-claim-by-enrollment-list.html) document. 

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 3
- Package version: 1.0.0
- Build package: io.swagger.codegen.languages.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import enrollment 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import enrollment
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import enrollment
from enrollment.rest import ApiException
from pprint import pprint

# Configure API key authorization: Bearer
enrollment.configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# enrollment.configuration.api_key_prefix['Authorization'] = 'Bearer'
# create an instance of the API class
api_instance = enrollment.PublicAPIApi()
enrollment_identities = '/path/to/file.txt' # file | The `CSV` file containing the enrollment IDs. The maximum file size is 10MB. 

try:
    # Bulk upload
    api_response = api_instance.create_bulk_device_enrollment(enrollment_identities)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling PublicAPIApi->create_bulk_device_enrollment: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://api.us-east-1.mbedcloud.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*PublicAPIApi* | [**create_bulk_device_enrollment**](docs/PublicAPIApi.md#create_bulk_device_enrollment) | **POST** /v3/device-enrollments-bulk-uploads | Bulk upload
*PublicAPIApi* | [**create_device_enrollment**](docs/PublicAPIApi.md#create_device_enrollment) | **POST** /v3/device-enrollments | Place an enrollment claim for one or several devices.
*PublicAPIApi* | [**delete_bulk_device_enrollment**](docs/PublicAPIApi.md#delete_bulk_device_enrollment) | **POST** /v3/device-enrollments-bulk-deletes | Bulk delete
*PublicAPIApi* | [**delete_device_enrollment**](docs/PublicAPIApi.md#delete_device_enrollment) | **DELETE** /v3/device-enrollments/{id} | Delete an enrollment by ID.
*PublicAPIApi* | [**get_bulk_device_enrollment**](docs/PublicAPIApi.md#get_bulk_device_enrollment) | **GET** /v3/device-enrollments-bulk-uploads/{id} | Get bulk upload entity
*PublicAPIApi* | [**get_bulk_device_enrollment_delete**](docs/PublicAPIApi.md#get_bulk_device_enrollment_delete) | **GET** /v3/device-enrollments-bulk-deletes/{id} | Get bulk delete entity
*PublicAPIApi* | [**get_device_enrollment**](docs/PublicAPIApi.md#get_device_enrollment) | **GET** /v3/device-enrollments/{id} | Get details of an enrollment by ID.
*PublicAPIApi* | [**get_device_enrollments**](docs/PublicAPIApi.md#get_device_enrollments) | **GET** /v3/device-enrollments | Get enrollment list.


## Documentation For Models

 - [BulkResponse](docs/BulkResponse.md)
 - [EnrollmentId](docs/EnrollmentId.md)
 - [EnrollmentIdentities](docs/EnrollmentIdentities.md)
 - [EnrollmentIdentity](docs/EnrollmentIdentity.md)
 - [ErrorResponse](docs/ErrorResponse.md)
 - [Field](docs/Field.md)


## Documentation For Authorization


## Bearer

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header


## Author



