# mds
Pelion Device Management Connect API allows web applications to communicate with devices. You can subscribe to device resources and read/write values to them. Device Management Connect allows connectivity to devices by queueing requests and caching resource values.

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 2
- Package version: 1.0.0
- Build package: io.swagger.codegen.languages.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import mds 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import mds
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import mds
from mds.rest import ApiException
from pprint import pprint

# Configure API key authorization: Bearer
mds.configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# mds.configuration.api_key_prefix['Authorization'] = 'Bearer'
# create an instance of the API class
api_instance = mds.DeviceRequestsApi()
device_id = 'device_id_example' # str | The device ID generated by Device Management.
async_id = 'async_id_example' # str | The client-generated ID for matching the correct response delivered via a notification.
body = mds.DeviceRequest() # DeviceRequest | Device request to send.

try:
    # Send an async request to device
    api_instance.create_async_request(device_id, async_id, body)
except ApiException as e:
    print("Exception when calling DeviceRequestsApi->create_async_request: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.us-east-1.mbedcloud.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DeviceRequestsApi* | [**create_async_request**](docs/DeviceRequestsApi.md#create_async_request) | **POST** /v2/device-requests/{device-id} | Send an async request to device
*EndpointsApi* | [**get_connected_endpoints**](docs/EndpointsApi.md#get_connected_endpoints) | **GET** /v2/endpoints | (DEPRECATED) List registered endpoints. The number of returned endpoints is currently limited to 200.
*EndpointsApi* | [**get_endpoint_resources**](docs/EndpointsApi.md#get_endpoint_resources) | **GET** /v2/endpoints/{device-id} | List the resources on an endpoint
*NotificationsApi* | [**delete_long_poll_channel**](docs/NotificationsApi.md#delete_long_poll_channel) | **DELETE** /v2/notification/pull | Delete notification Long Poll channel
*NotificationsApi* | [**deregister_webhook**](docs/NotificationsApi.md#deregister_webhook) | **DELETE** /v2/notification/callback | Delete callback URL
*NotificationsApi* | [**get_webhook**](docs/NotificationsApi.md#get_webhook) | **GET** /v2/notification/callback | Check callback URL
*NotificationsApi* | [**long_poll_notifications**](docs/NotificationsApi.md#long_poll_notifications) | **GET** /v2/notification/pull | Get notifications using Long Poll
*NotificationsApi* | [**register_webhook**](docs/NotificationsApi.md#register_webhook) | **PUT** /v2/notification/callback | Register a callback URL
*ResourcesApi* | [**delete_resource_path**](docs/ResourcesApi.md#delete_resource_path) | **DELETE** /v2/endpoints/{device-id}/{resourcePath} | Delete a resource path
*ResourcesApi* | [**execute_or_create_resource**](docs/ResourcesApi.md#execute_or_create_resource) | **POST** /v2/endpoints/{device-id}/{resourcePath} | Execute a function on a Resource or create new Object instance
*ResourcesApi* | [**get_resource_value**](docs/ResourcesApi.md#get_resource_value) | **GET** /v2/endpoints/{device-id}/{resourcePath} | Read from a resource
*ResourcesApi* | [**update_resource_value**](docs/ResourcesApi.md#update_resource_value) | **PUT** /v2/endpoints/{device-id}/{resourcePath} | Write to a resource or use write-attributes for a resource
*SubscriptionsApi* | [**add_resource_subscription**](docs/SubscriptionsApi.md#add_resource_subscription) | **PUT** /v2/subscriptions/{device-id}/{resourcePath} | Subscribe to a resource path
*SubscriptionsApi* | [**check_resource_subscription**](docs/SubscriptionsApi.md#check_resource_subscription) | **GET** /v2/subscriptions/{device-id}/{resourcePath} | Read subscription status
*SubscriptionsApi* | [**delete_endpoint_subscriptions**](docs/SubscriptionsApi.md#delete_endpoint_subscriptions) | **DELETE** /v2/subscriptions/{device-id} | Delete subscriptions from an endpoint
*SubscriptionsApi* | [**delete_pre_subscriptions**](docs/SubscriptionsApi.md#delete_pre_subscriptions) | **DELETE** /v2/subscriptions | Remove pre-subscriptions
*SubscriptionsApi* | [**delete_resource_subscription**](docs/SubscriptionsApi.md#delete_resource_subscription) | **DELETE** /v2/subscriptions/{device-id}/{resourcePath} | Remove a subscription
*SubscriptionsApi* | [**get_endpoint_subscriptions**](docs/SubscriptionsApi.md#get_endpoint_subscriptions) | **GET** /v2/subscriptions/{device-id} | Read endpoints subscriptions
*SubscriptionsApi* | [**get_pre_subscriptions**](docs/SubscriptionsApi.md#get_pre_subscriptions) | **GET** /v2/subscriptions | Get pre-subscriptions
*SubscriptionsApi* | [**update_pre_subscriptions**](docs/SubscriptionsApi.md#update_pre_subscriptions) | **PUT** /v2/subscriptions | Set pre-subscriptions


## Documentation For Models

 - [AsyncID](docs/AsyncID.md)
 - [AsyncIDResponse](docs/AsyncIDResponse.md)
 - [DeviceRequest](docs/DeviceRequest.md)
 - [Endpoint](docs/Endpoint.md)
 - [EndpointData](docs/EndpointData.md)
 - [NotificationData](docs/NotificationData.md)
 - [NotificationMessage](docs/NotificationMessage.md)
 - [Presubscription](docs/Presubscription.md)
 - [PresubscriptionArray](docs/PresubscriptionArray.md)
 - [Resource](docs/Resource.md)
 - [ResourcePath](docs/ResourcePath.md)
 - [ResourcesData](docs/ResourcesData.md)
 - [SubscriptionsList](docs/SubscriptionsList.md)
 - [Webhook](docs/Webhook.md)


## Documentation For Authorization


## Bearer

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header


## Author



